import { createApp } from 'vue';
import { createPinia } from 'pinia';
import App from "./App.vue";
import { invoke } from "@tauri-apps/api/core";
import { listen } from '@tauri-apps/api/event';
import { processSerialData } from './utils/dataFetcher';

const app = createApp(App);
const pinia = createPinia();
app.use(pinia);
app.mount("#app");

function sleep(seconds: number): Promise<void> {
  return new Promise((resolve) => setTimeout(resolve, seconds * 1000));
}

async function setup() {
  console.log("前端应用启动..");
  // 增加延迟时间，确保欢迎页面有足够显示时间
  await sleep(3);
  console.log("前端应用启动完成111");
  // 调用后端应用
  invoke("set_complete", { task: "frontend" });

  // 监听来自Rust后端的串口数据事件
  await listen('serial_data', (event) => {
    console.log('serial_data', event);
    // event.payload 是从Rust发送过来的数据
    const data = event.payload as number[]; // 假设数据是字节数组
    processSerialData(data);
  });
}

window.addEventListener("DOMContentLoaded", () => {
    console.log("前端应用启动222");
    setup();
});
